{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "DiffBind",
            "doc": "Compute differentially bound sites from multiple ChIP-seq experiments using affinity (quantitative) data",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/bioconductor-diffbind:3.8.0--r42hc247a5b_0",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "bioconductor-diffbind",
                            "version": [
                                "3.8.0"
                            ],
                            "specs": [
                                "https://anaconda.org/bioconda/bioconductor-diffbind"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "diffbind.R",
                            "entry": "args = commandArgs(trailingOnly=TRUE)\nbedDir = args[2]\nbamDir = args[3]\nminMembers = as.numeric(args[4])\npeakcaller = args[5]\npaired = FALSE\nif (length(args) == 6){\n  paired = TRUE\n}\n\nlibrary(\"DiffBind\")\nsamples <- read.csv(args[1],sep = \"\\t\")\nprefix <- paste('condition_', paste(unique(samples$Condition), collapse = '_vs_'), sep='')\nbed <- c()\nbam <- c()\ncallers <- c()\nfor(i in samples$id){\n    f <- paste(bedDir,\"/\", i,\"_sorted_peaks.narrowPeak\", sep=\"\")\n    bed <- c(bed,f)\n    f <- paste(bamDir,\"/\", i,\"_sorted.bam\", sep=\"\")\n    bam <- c(bam,f)\n    callers <- c(callers, peakcaller)\n}\nsamples$Peaks <- bed\nsamples$bamReads <- bam\nsamples$PeakCaller <- callers\nsamples\nDBdata <- dba(sampleSheet=samples)\nDBdata <- dba.count(DBdata)\nif (paired){\n    print(\"Doing paired analysis\")\n    DBdata <- dba.contrast(DBdata, categories=DBA_CONDITION, block=DBA_REPLICATE, minMembers = minMembers)\n}else{\n  print(\"Doing unpaired analysis\")\n    DBdata <- dba.contrast(DBdata, categories=DBA_CONDITION, minMembers = minMembers)\n}\nDBdata <- dba.analyze(DBdata, method=DBA_DESEQ2)\nDBdata <- dba.analyze(DBdata, method=DBA_EDGER)\nDBdata\npng(paste(prefix, \"diffbind_deseq2_plot.png\", sep='_'))\nplot(DBdata, method=DBA_DESEQ2)\ndev.off()\npng(paste(prefix, \"diffbind_deseq2_plotHeatmap.png\", sep='_'))\ndba.plotHeatmap(DBdata, contrast=1, correlations=FALSE, method=DBA_DESEQ2)\ndev.off()\npng(paste(prefix, \"diffbind_deseq2_plotMA.png\", sep='_'))\ndba.plotMA(DBdata, method=DBA_DESEQ2)\ndev.off()\npng(paste(prefix, \"diffbind_deseq2_plotVolcano.png\", sep='_'))\ndba.plotVolcano(DBdata, method=DBA_DESEQ2)\ndev.off()\npng(paste(prefix, \"diffbind_deseq2_plotPCA.png\", sep='_'))\ndba.plotPCA(DBdata, method=DBA_DESEQ2)\ndev.off()\npng(paste(prefix, \"diffbind_deseq2_plotPCA_contrast.png\", sep='_'))\ndba.plotPCA(DBdata, contrast = 1, method=DBA_DESEQ2)\ndev.off()\npng(paste(prefix, \"diffbind_deseq2_plotBox.png\", sep='_'))\ndba.plotBox(DBdata, method=DBA_DESEQ2)\ndev.off()\npng(paste(prefix, \"diffbind_edgeR_plot.png\", sep='_'))\nplot(DBdata, method=DBA_EDGER)\ndev.off()\npng(paste(prefix, \"diffbind_edgeR_plotHeatmap.png\", sep='_'))\ndba.plotHeatmap(DBdata, contrast=1, correlations=FALSE, method=DBA_EDGER)\ndev.off()\npng(paste(prefix, \"diffbind_edgeR_plotMA.png\", sep='_'))\ndba.plotMA(DBdata, method=DBA_EDGER)\ndev.off()\npng(paste(prefix, \"diffbind_edgeR_plotVolcano.png\", sep='_'))\ndba.plotVolcano(DBdata, method=DBA_EDGER)\ndev.off()\npng(paste(prefix, \"diffbind_edgeR_plotPCA.png\", sep='_'))\ndba.plotPCA(DBdata, method=DBA_EDGER)\ndev.off()\npng(paste(prefix, \"diffbind_edgeR_plotPCA_contrast.png\", sep='_'))\ndba.plotPCA(DBdata, contrast = 1, method=DBA_EDGER)\ndev.off()\npng(paste(prefix, \"diffbind_edgeR_plotBox.png\", sep='_'))\ndba.plotBox(DBdata, method=DBA_EDGER)\ndev.off()\n\nreport <- dba.report(DBdata, method=DBA_EDGER, th=1, bCounts=TRUE, DataType=DBA_DATA_FRAME)\nscore <- -10*(log10(report$FDR))\nwrite.table(cbind(report,rownames(report),score),\n            paste(prefix, \"diffbind_edgeR_report.xls\", sep='_'), quote=FALSE, sep=\"\\t\",\n            row.names=FALSE)\nwrite.table(cbind(report[,1:3],rownames(report),score),\n            paste(prefix, \"diffbind_edgeR_report.bed\", sep='_'), quote=FALSE, sep=\"\\t\",\n            row.names=FALSE, col.names=FALSE)\n\nreport <- dba.report(DBdata, method=DBA_DESEQ2, th=1, bCounts=TRUE, DataType=DBA_DATA_FRAME)\nscore <- -10*(log10(report$FDR))\nwrite.table(cbind(report,rownames(report),score),\n           paste(prefix, \"diffbind_deseq2_report.xls\", sep='_'), quote=FALSE, sep=\"\\t\",\n            row.names=FALSE)\nwrite.table(cbind(report[,1:3],rownames(report),score),\n            paste(prefix, \"diffbind_deseq2_report.bed\", sep='_'), quote=FALSE, sep=\"\\t\",\n            row.names=FALSE, col.names=FALSE)\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#diffbind.cwl/bamDir"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#diffbind.cwl/bedDir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#diffbind.cwl/factor"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#diffbind.cwl/minMembers"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#diffbind.cwl/paired"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#diffbind.cwl/peakcaller"
                }
            ],
            "baseCommand": [
                "Rscript",
                "--vanilla",
                "diffbind.R"
            ],
            "id": "#diffbind.cwl",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.bed"
                    },
                    "id": "#diffbind.cwl/outbed"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.png"
                    },
                    "id": "#diffbind.cwl/outpng"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.xls"
                    },
                    "id": "#diffbind.cwl/outxls"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "doc": "This workflow runs Diffbind in parallel",
            "label": "diffbind_parallel",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#main/bamDir"
                },
                {
                    "type": "Directory",
                    "id": "#main/bedDir"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/factors"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "id": "#main/minMembers"
                },
                {
                    "type": "string",
                    "id": "#main/peakcaller"
                }
            ],
            "outputs": [
                {
                    "outputSource": "#main/diffbind/outbed",
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#main/diffbind_outbed"
                },
                {
                    "outputSource": "#main/diffbind/outpng",
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#main/diffbind_outpng"
                },
                {
                    "outputSource": "#main/diffbind/outxls",
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#main/diffbind_outxls"
                }
            ],
            "steps": [
                {
                    "run": "#diffbind.cwl",
                    "scatter": [
                        "#main/diffbind/factor",
                        "#main/diffbind/minMembers"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/bamDir",
                            "id": "#main/diffbind/bamDir"
                        },
                        {
                            "source": "#main/bedDir",
                            "id": "#main/diffbind/bedDir"
                        },
                        {
                            "source": "#main/factors",
                            "id": "#main/diffbind/factor"
                        },
                        {
                            "source": "#main/minMembers",
                            "id": "#main/diffbind/minMembers"
                        },
                        {
                            "source": "#main/peakcaller",
                            "id": "#main/diffbind/peakcaller"
                        }
                    ],
                    "out": [
                        "#main/diffbind/outpng",
                        "#main/diffbind/outxls",
                        "#main/diffbind/outbed"
                    ],
                    "id": "#main/diffbind"
                }
            ],
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-4108-5982",
                    "http://schema.org/email": "mailto:r78v10a07@gmail.com",
                    "http://schema.org/name": "Roberto Vera Alvarez"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
